from plain.urls import RouterBase, path, register_router

from . import views


@register_router
class Router(RouterBase):
    namespace = "loginlink"
    urls = [
        path("sent/", views.LoginLinkSentView.as_view(), name="sent"),
        path("failed/", views.LoginLinkFailedView.as_view(), name="failed"),
        path("token/<str:token>/", views.LoginLinkLoginView.as_view(), name="login"),
    ]



# (generated with --quick)

from loginlink import signing
from typing import Any

BadSignature: Any
SignatureExpired: Any
get_user_model: Any
reverse: Any

class LoginLinkChanged(Exception): ...

class LoginLinkExpired(Exception): ...

class LoginLinkInvalid(Exception): ...

def generate_link_url(*, request, user, email, expires_in) -> Any: ...
def get_link_token_user(token) -> Any: ...



# (generated with --quick)

import time
import zlib
from typing import Any

JSONSerializer: Any
SignatureExpired: Any
Signer: Any
b62_decode: Any
b62_encode: Any
b64_decode: Any
b64_encode: Any

class ExpiringSigner(Any):
    __doc__: str
    def sign(self, value, expires_in) -> Any: ...
    def sign_object(self, obj, serializer = ..., compress = ..., expires_in = ...) -> Any: ...
    def unsign(self, value) -> Any: ...
    def unsign_object(self, signed_obj, serializer = ...) -> Any: ...

def dumps(obj, key = ..., salt = ..., serializer = ..., compress = ..., expires_in = ...) -> Any: ...
def loads(s, key = ..., salt = ..., serializer = ..., fallback_keys = ...) -> Any: ...
